@@ -1,7 +1,8 @@
 PACKAGE_NAME: str = 'mkdocs_markmap'
 PROJECT_NAME: str = PACKAGE_NAME.replace('_', '-')
-PROJECT_VERSION: str = '2.2.2'
+PROJECT_VERSION: str = '2.3.0'
 
 OWNER: str = 'neatc0der'
-REPOSITORY_NAME: str = f'{OWNER}/{PROJECT_NAME}'
+ORGANISATION: str = 'markmap'
+REPOSITORY_NAME: str = f'{ORGANISATION}/{PROJECT_NAME}'
 REPOSITORY_URL: str = f'https://github.com/{REPOSITORY_NAME}'
